@@ -21,7 +21,14 @@
 
 
         // Bind events for threaded comment reply
-        $('.comment-reply-link').live('click', showThreadedReplyForm);
+        if($.fn.on) {
+            // jQuery 1.7+
+            $('body').on('click', '.comment-reply-link', showThreadedReplyForm);
+        }
+        else {
+            $('.comment-reply-link').live('click', showThreadedReplyForm);
+        }
+
         $('.comment-cancel-reply-link').click(cancelThreadedReplyForm);
         $('.js-comments-form').wrap('<div class="js-comments-form-orig-position"></div>');
 
@@ -236,6 +243,11 @@
         }
         else
         {
+            // Each top-level of django-threadedcomments starts in a new <ul>
+            // when you use the comment.open / comment.close logic as prescribed.
+            if(data['use_threadedcomments'])
+                html = '<ul class="comment-list-wrapper"><li class="comment-wrapper">' + html + '</li></ul>';
+
             var $comments = getCommentsDiv();
             $comments.append(html).removeClass('empty');
         }
